@@ -8,7 +8,7 @@
  */
 
 /*
- * $Id: main.c,v 1.96 2004/10/09 19:08:36 florian Exp $
+ * $Id: main.c,v 1.100 2004/10/12 14:23:18 florian Exp $
  *
  */
 
@@ -40,6 +40,7 @@
 #include "main.h"
 #include "export.h"
 #include "import-vcard.h"
+#include "finddlg.h"
 
 #define SYSTEM_PIXMAPS_DIR PREFIX "/share/pixmaps/"
 #define MY_PIXMAPS_DIR "gpe-contacts/"
@@ -196,20 +197,21 @@ delete_contact (GtkWidget * widget, gpointer d)
       if (gpe_question_ask (_("Really delete this contact?"), _("Confirm"), 
 			    "question", "!gtk-cancel", NULL, "!gtk-delete", NULL, NULL) == 1)
         {
+          gtk_tree_view_get_cursor(GTK_TREE_VIEW(list_view), &path, NULL);
+          if (path) 
+            {
+              if (!gtk_tree_path_prev(path))
+                gtk_tree_path_next(path);
+            }
+          else
+            path = gtk_tree_path_new_first();
           if (db_delete_by_uid (uid))
             {
-              gtk_tree_view_get_cursor(GTK_TREE_VIEW(list_view),&path,NULL);
-              if (path) 
-                {
-                  if (!gtk_tree_path_prev(path))
-                    gtk_tree_path_next(path);
-                }
-              else
-                path = gtk_tree_path_new_first();
-              gtk_tree_view_set_cursor(GTK_TREE_VIEW(list_view),path,NULL,FALSE);
-              gtk_tree_path_free(path);
               update_display ();
+              gtk_tree_view_set_cursor(GTK_TREE_VIEW(list_view), path, 
+                                       NULL, FALSE);    
             }
+          gtk_tree_path_free(path);
         }
     }
 }
@@ -509,8 +511,7 @@ show_details (struct person *p)
               lleft = ((GtkTableChild *) pchild)->widget;
               tagname =
                 db_get_config_tag (CONFIG_PANEL,
-                           g_strdup (gtk_label_get_text
-                             (GTK_LABEL (lleft))));
+                           g_strdup (gtk_label_get_text(GTK_LABEL (lleft))));
               curtag = db_find_tag (p, tagname);
               if (curtag != NULL)
                 {
@@ -655,54 +656,56 @@ match_for_search (struct person *p, const gchar *text, struct gpe_pim_category *
   gchar *fn;
   gchar *name;
   gchar *company;
-  
   if ((text == NULL) && (cat == NULL)) /* some speedup */
     return TRUE;
   
-  if (p->given_name)
-    gn = g_utf8_strdown(p->given_name, -1);
-  else
-    gn = g_strdup("");
-  
-  if (p->middle_name)
-    mn = g_utf8_strdown(p->middle_name, -1);
-  else
-    mn = g_strdup("");
-  
-  if (p->family_name)
-    fn = g_utf8_strdown(p->family_name, -1);
-  else
-    fn = g_strdup("");
-  
-  if ((p->name) && strlen(p->name))
-    name = g_utf8_strdown(p->name, -1);
-  else
-    name = g_strdup("");
-  
-  if (p->company)
-    company = g_utf8_strdown(p->company, -1);
-  else
-    company = g_strdup("");
-  
-  if (!g_str_has_prefix(gn, text) 
-      && !g_str_has_prefix(fn, text) 
-      && !g_str_has_prefix(name, text)
-      && !g_str_has_prefix(mn, text)
-      && !g_str_has_prefix(company, text))
+  if (text)
     {
+      if (p->given_name)
+        gn = g_utf8_strdown(p->given_name, -1);
+      else
+        gn = g_strdup("");
+      
+      if (p->middle_name)
+        mn = g_utf8_strdown(p->middle_name, -1);
+      else
+        mn = g_strdup("");
+      
+      if (p->family_name)
+        fn = g_utf8_strdown(p->family_name, -1);
+      else
+        fn = g_strdup("");
+      
+      if ((p->name) && strlen(p->name))
+        name = g_utf8_strdown(p->name, -1);
+      else
+        name = g_strdup("");
+      
+      if (p->company)
+        company = g_utf8_strdown(p->company, -1);
+      else
+        company = g_strdup("");
+      
+      if (!g_str_has_prefix(gn, text) 
+          && !g_str_has_prefix(fn, text) 
+          && !g_str_has_prefix(name, text)
+          && !g_str_has_prefix(mn, text)
+          && !g_str_has_prefix(company, text))
+        {
+          if (gn) g_free(gn);
+          if (mn) g_free(mn);
+          if (fn) g_free(fn);
+          if (name) g_free(name);
+          if (company) g_free(company);
+          return FALSE;
+        }
       if (gn) g_free(gn);
       if (mn) g_free(mn);
       if (fn) g_free(fn);
       if (name) g_free(name);
       if (company) g_free(company);
-      return FALSE;
     }
-  if (gn) g_free(gn);
-  if (mn) g_free(mn);
-  if (fn) g_free(fn);
-  if (name) g_free(name);
-  if (company) g_free(company);
-    
+
   if (cat)
     {
       GSList *l;
@@ -778,6 +781,52 @@ do_search (GObject *obj, GtkWidget *entry)
   gtk_tree_path_free(path);
 }
 
+static void
+do_find (void)
+{
+  guint category = gtk_option_menu_get_history (GTK_OPTION_MENU (categories_smenu));
+  GSList *all_entries = do_find_contacts(GTK_WINDOW(mainw)), *iter = NULL;
+  struct gpe_pim_category *c = NULL;
+  GtkTreePath *path;
+
+  if (category)
+    {
+      GSList *l = gpe_pim_categories_list ();
+      GSList *ll = g_slist_nth (l, category - 1);
+
+      if (ll)
+        c = ll->data;
+
+      g_slist_free (l);
+    }
+
+  all_entries = g_slist_sort (all_entries, (GCompareFunc)sort_entries);
+
+  gtk_list_store_clear (list_store);
+  show_details(NULL);
+
+  for (iter = all_entries; iter; iter = iter->next)
+    {
+      struct person *p = iter->data;
+      GtkTreeIter titer;
+      
+      if (match_for_search (p, NULL, c))
+        {
+	      gtk_list_store_append (list_store, &titer);
+	      gtk_list_store_set (list_store, &titer, 0, p->name, 1, p->id, -1);
+        }
+
+      discard_person (p);
+    }
+  
+  g_slist_free (all_entries);
+  
+  /* select first */
+  path = gtk_tree_path_new_first();
+  gtk_tree_view_set_cursor(GTK_TREE_VIEW(list_view), path, NULL, FALSE);
+  gtk_tree_path_free(path);
+}
+
 #define SEARCH_DELAY  200
 
 static guint search_seq;
@@ -870,7 +919,7 @@ window_key_press_event (GtkWidget *widget, GdkEventKey *k, GtkTreeView *tree)
         switch (k->keyval)
           {
             case GDK_f:
-              gtk_widget_grab_focus(search_entry);
+              do_find();
               return TRUE;
             break;
             case GDK_q:
@@ -996,7 +1045,8 @@ search_entry_key_press_event (GtkWidget *widget, GdkEventKey *k, GtkWidget *tool
   }
   if (k->keyval == GDK_Escape)
   {
-    gtk_editable_delete_text(GTK_EDITABLE(widget),0,-1);
+    gtk_entry_set_text(GTK_ENTRY(widget), " ");
+    gtk_editable_delete_text(GTK_EDITABLE(widget), 0, -1);
     return TRUE;
   }
   return FALSE;
@@ -1093,7 +1143,7 @@ on_main_focus(GtkWindow *window,  GdkEventExpose *event,gpointer user_data)
 }
 
 static GtkWidget *
-create_main (gboolean show_config_button)
+create_main (gboolean edit_structure)
 {
   GtkWidget *main_window;
   GtkWidget *vbox1;
@@ -1164,11 +1214,18 @@ create_main (gboolean show_config_button)
                                       NULL, pw, G_CALLBACK (show_details_window), NULL);
       g_object_set_data (G_OBJECT (main_window), "details-button", btnDetails);
     }
-
-  if (show_config_button)
-    gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_PROPERTIES,
-			    _("Properties"), _("Tap here to configure the program."),
-  			    G_CALLBACK (configure), NULL, -1);
+  else
+    {
+      gtk_toolbar_append_space(GTK_TOOLBAR(toolbar));
+    
+      b = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_FIND,
+				_("Find a contact by searching for any data."), NULL,
+				G_CALLBACK (do_find), NULL, -1);
+    }
+  
+  gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_PROPERTIES,
+			    _("Properties"), _("Tap here to configure this program."),
+  			    G_CALLBACK (configure), (gpointer)edit_structure, -1);
 				
   gtk_toolbar_append_space(GTK_TOOLBAR(toolbar));
 
@@ -1189,9 +1246,17 @@ create_main (gboolean show_config_button)
   gtk_container_add (GTK_CONTAINER (scrolled_window), list_view);
   if (mode_landscape)
     {
-      hbox1 = gtk_hbox_new(FALSE,gpe_get_boxspacing());
-      gtk_box_pack_start (GTK_BOX (hbox1), scrolled_window, FALSE, TRUE, 0);
+      gchar *cfgval = db_get_config_tag(CONFIG_LIST, "pos");
+      hbox1 = gtk_hbox_new(FALSE, gpe_get_boxspacing());
       gtk_box_pack_start (GTK_BOX (vbox1), hbox1, TRUE, TRUE, 0);
+      if ((cfgval) && !strcmp(cfgval, "right"))
+        gtk_box_pack_end (GTK_BOX (hbox1), scrolled_window, FALSE, TRUE, 0);
+      else
+        gtk_box_pack_start (GTK_BOX (hbox1), scrolled_window, FALSE, TRUE, 0);
+      if (cfgval)
+        g_free(cfgval);
+      g_object_set_data(G_OBJECT(main_window), "hbox", hbox1);
+      g_object_set_data(G_OBJECT(main_window), "swlist", scrolled_window);
     }
   else  
     {
@@ -1213,8 +1278,8 @@ create_main (gboolean show_config_button)
   hbox3 = gtk_hbox_new (FALSE, 0);
   if (mode_landscape)
     {
-       gtk_container_set_border_width(GTK_CONTAINER(hbox3),gpe_get_border());
-       gtk_box_set_spacing(GTK_BOX(hbox3),gpe_get_boxspacing());
+       gtk_container_set_border_width(GTK_CONTAINER(hbox3), gpe_get_border());
+       gtk_box_set_spacing(GTK_BOX(hbox3), gpe_get_boxspacing());
     }
   gtk_box_pack_start (GTK_BOX (vbox1), hbox3, FALSE, FALSE, 0);
 
@@ -1268,7 +1333,7 @@ create_main (gboolean show_config_button)
   
   if (mode_landscape)
     {
-      gtk_container_set_border_width(GTK_CONTAINER(pDetail),gpe_get_border());
+      gtk_container_set_border_width(GTK_CONTAINER(pDetail), gpe_get_border());
       gtk_box_pack_start (GTK_BOX (hbox1), pDetail, TRUE, TRUE, 0);
     }
   else
@@ -1332,7 +1397,7 @@ int
 main (int argc, char *argv[])
 {
   int arg;
-  gboolean show_config_button = TRUE;
+  gboolean edit_structure = TRUE;
   gchar *ifile = NULL;
   GtkTreePath *path;
   
@@ -1355,7 +1420,7 @@ main (int argc, char *argv[])
   {
     if (arg == 'n')
       {
-        show_config_button = FALSE;
+        edit_structure = FALSE;
         break;
       }
     if (arg == 'i')
@@ -1399,7 +1464,7 @@ main (int argc, char *argv[])
 
   list_store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
 
-  mainw = create_main (show_config_button);
+  mainw = create_main (edit_structure);
   popup_menu = create_popup (mainw);
   update_categories ();
   show_details (NULL);
